@@ -1,7 +1,7 @@
 package App::PMUtils;
 
-our $DATE = '2020-06-12'; # DATE
-our $VERSION = '0.734'; # VERSION
+our $DATE = '2021-07-27'; # DATE
+our $VERSION = '0.735'; # VERSION
 
 use 5.010001;
 use strict;
@@ -247,7 +247,7 @@ App::PMUtils - Command-line utilities related to Perl modules
 
 =head1 VERSION
 
-This document describes version 0.734 of App::PMUtils (from Perl distribution App-PMUtils), released on 2020-06-12.
+This document describes version 0.735 of App::PMUtils (from Perl distribution App-PMUtils), released on 2021-07-27.
 
 =head1 SYNOPSIS
 
@@ -316,6 +316,12 @@ modules:
 
 The main purpose of these utilities is tab completion.
 
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto
+
+Steven Haryanto <sharyanto@cpan.org>
+
 =head1 FUNCTIONS
 
 
@@ -323,7 +329,7 @@ The main purpose of these utilities is tab completion.
 
 Usage:
 
- pmdir(%args) -> [status, msg, payload, meta]
+ pmdir(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Get directory of locally installed Perl moduleE<sol>prefix.
 
@@ -357,12 +363,12 @@ Absolutify each path.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -372,7 +378,7 @@ Return value:  (any)
 
 Usage:
 
- pmpath(%args) -> [status, msg, payload, meta]
+ pmpath(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Get path to locally installed Perl module.
 
@@ -416,12 +422,12 @@ and it won't change directory if the module doesn't exist.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -431,7 +437,7 @@ Return value:  (any)
 
 Usage:
 
- pmunlink(%args) -> [status, msg, payload, meta]
+ pmunlink(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Unlink (remove) locally installed Perl module.
 
@@ -471,12 +477,12 @@ Pass -dry_run=E<gt>1 to enable simulation mode.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -551,6 +557,8 @@ L<App::IODUtils>, utilities related to L<IOD> configuration files.
 
 L<App::LedgerUtils>, utilities related to Ledger CLI files.
 
+L<App::PerlReleaseUtils>, utilities related to Perl distribution releases.
+
 L<App::PlUtils>, utilities related to Perl scripts.
 
 L<App::PMUtils>, utilities related to Perl modules.
@@ -567,7 +575,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
