@@ -2,8 +2,8 @@
 
 package App::pmgrep;
 
-our $DATE = '2020-06-12'; # DATE
-our $VERSION = '0.734'; # VERSION
+our $DATE = '2021-07-27'; # DATE
+our $VERSION = '0.735'; # VERSION
 
 use 5.010001;
 use strict;
@@ -144,7 +144,7 @@ App::pmgrep - Print lines from installed Perl module sources matching a pattern
 
 =head1 VERSION
 
-This document describes version 0.734 of App::pmgrep (from Perl distribution App-PMUtils), released on 2020-06-12.
+This document describes version 0.735 of App::pmgrep (from Perl distribution App-PMUtils), released on 2021-07-27.
 
 =head1 FUNCTIONS
 
@@ -153,7 +153,7 @@ This document describes version 0.734 of App::pmgrep (from Perl distribution App
 
 Usage:
 
- pmgrep(%args) -> [status, msg, payload, meta]
+ pmgrep(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Print lines from installed Perl module sources matching a pattern.
 
@@ -179,12 +179,21 @@ Arguments ('*' denotes required arguments):
 
 Require all patterns to match, instead of just one.
 
-=item * B<color> => I<str>
+=item * B<color> => I<str> (default: "auto")
 
 =item * B<count> => I<true>
 
 Supress normal output, return a count of matching lines.
 
+=item * B<dash_prefix_inverts> => I<bool>
+
+When given pattern that starts with dash "-FOO", make it to mean "^(?!.*FOO)".
+
+This is a convenient way to search for lines that do not match a pattern.
+Instead of using C<-v> to invert the meaning of all patterns, this option allows
+you to invert individual pattern using the dash prefix, which is also used by
+Google search and a few other search engines.
+
 =item * B<ignore_case> => I<bool>
 
 =item * B<invert_match> => I<bool>
@@ -197,7 +206,7 @@ Invert the sense of matching.
 
 If not specified, all installed Perl modules will be searched.
 
-=item * B<pattern> => I<re>
+=item * B<pattern> => I<str>
 
 =item * B<pm> => I<bool> (default: 1)
 
@@ -215,19 +224,19 @@ Whether to include .pod files.
 
 =item * B<recursive> => I<true>
 
-=item * B<regexps> => I<array[re]>
+=item * B<regexps> => I<array[str]>
 
 
 =back
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -253,7 +262,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
